@@ -7,7 +7,7 @@ from typing import TYPE_CHECKING, Any, Callable
 
 from bleak import BleakScanner
 
-from .consts import EMBER_BLUETOOTH_NAMES, EMBER_SERVICE_UUID, USES_BLUEZ
+from .consts import EMBER_BLUETOOTH_NAMES, IS_LINUX, MugCharacteristic
 
 if TYPE_CHECKING:
     from bleak.backends.device import BLEDevice
@@ -19,7 +19,7 @@ logger = logging.getLogger(__name__)
 
 def build_scanner_kwargs(adapter: str | None = None) -> dict[str, Any]:
     """Add Adapter to kwargs for scanner if specified and using BlueZ."""
-    if adapter and not USES_BLUEZ:
+    if adapter and IS_LINUX is not True:
         raise ValueError('The adapter option is only valid for the Linux BlueZ Backend.')
     return {'adapter': adapter} if adapter else {}
 
@@ -27,7 +27,7 @@ def build_scanner_kwargs(adapter: str | None = None) -> dict[str, Any]:
 async def discover_mugs(mac: str | None = None, adapter: str | None = None, wait: int = 5) -> list[BLEDevice]:
     """Discover new mugs in pairing mode."""
     scanner_kwargs = build_scanner_kwargs(adapter)
-    async with BleakScanner(service_uuids=[str(EMBER_SERVICE_UUID)], **scanner_kwargs) as scanner:
+    async with BleakScanner(service_uuids=[str(MugCharacteristic.SERVICE)], **scanner_kwargs) as scanner:
         await asyncio.sleep(wait)
         if mac:
             mac = mac.lower()
